global wiodpath "PATH"
global datapath "PATH"
use "$wiodpath\wiot_full.dta", clear

* Prepare the dataset for aggregation
gen desc_row = "."
replace desc_row = "INT" if row_item <= 35
replace desc_row = "TIC" if row_item == 60
replace desc_row = "TAX" if row_item == 99
replace desc_row = "CIF" if row_item == 61
replace desc_row = "PUR_RES" if row_item == 62
replace desc_row = "PUF" if row_item == 62
replace desc_row = "VA" if row_item == 64
replace desc_row = "GO" if row_item == 69
replace desc_row = "MARG" if row_country == "ITM"


gen desc_col = "."
replace desc_col = "INT" if col_item <= 35
replace desc_col = "CON_HLD" if col_item == 37
replace desc_col = "CON_NGO" if col_item == 38
replace desc_col = "CON_GVT" if col_item == 39
replace desc_col = "GFCF" if col_item == 41
replace desc_col = "INV" if col_item == 42


* Mark domestic
*gen domestic=col_country==row_country
* Final use
*gen final=(desc_col == "CON_HLD" | desc_col == "CON_NGO" | desc_col == "CON_GVT" | desc_col == "GFCF" | desc_col == "INV")
gen final = col_item > 35
gen domestic=(row_country==col_country) 
gen DOM=(row_country==col_country) 

stop

preserve
*** Backward spillovers 
*** Summing up across columns (destinations) shares for each row
keep if final==0
keep if domestic==1
bysort year row_country row_item: egen total_use = total(value)
gen col_share = value / total_use

ren row_item row_item_org
ren col_item row_item
merge m:1 row_country row_item year using "$datapath\foreign_share.dta"
drop if _merge!=3

foreach var in va_real k_real l sales number  {
gen foreign_col_`var'_share = col_share * foreign_`var'_share
}

collapse (sum) foreign_col_*, by(row_country row_item_org year)
rename row_item_org row_item
ren foreign_col_* backward_*
save "$datapath\backward.dta", replace

restore
preserve
* Forward spillovers
*** Summing up across rows (origin) shares for each column
keep if final==0 | desc_row=="VA"
keep if domestic==1
bysort year col_country col_item: egen gross_output=total(value)
drop if desc_row=="VA"
keep if domestic==1
gen row_share = value / gross_output
merge m:1 row_country row_item year using "$datapath\foreign_share.dta"
drop if _merge!=3
foreach var in va_real k_real l sales number {
gen foreign_row_`var'_share = row_share * foreign_`var'_share
}
collapse (sum) foreign_row_*, by(row_country col_item year)
rename col_item row_item
ren foreign_row_* forward_*
save "$datapath\forward.dta", replace
restore
saveold temp, replace
* Compute aggregates
* Across rows
* I need: gross output, total intermediate use, value added, domestic intermediate use, foreign intermediate use

* Prepare the dataset for aggregation
* Intermediate and final exports
/*
preserve
keep if domestic==0
collapse (sum) value, by(year row_country row_item desc_row domestic final)

save "$datapath\int_exports.dta", replace
restore


preserve
keep if domestic==0
collapse (sum) value, by(col_country col_item year final)
reshape wide value, i(col_country col_item year) j(final)
ren col_country row_country
ren col_item row_item
ren value0 intermediate_imports
ren value1 final_imports
save "$datapath\imports.dta", replace
restore

preserve
keep if desc_row == "VA" | desc_row == "GO" | desc_row =="INT"
collapse (sum) value, by(col_country col_item year desc_row)
reshape wide value, i(col_country col_item year) j(desc_row) string
ren col_country row_country
ren col_item row_item
ren valueGO wiod_gross_output
ren valueVA wiod_value_added
ren valueINT wiod_intermediate_use
save "$datapath\output.dta", replace
restore
*/



***********Imports**************


preserve
* create a sectoral database: imported vs domestic intermediates
collapse (sum) value, by(year col_country col_item desc_row DOM final)
saveold out0, replace
keep if desc_row=="INT" & DOM==0 & final==0
drop desc_row DOM final
ren value intermediate_imports_dest
ren col_country row_country
ren col_item row_item
sort year row_country row_item
saveold intermediate_imports_by_dest, replace
restore

preserve
* create a sectoral database: imported vs domestic intermediates
collapse (sum) value, by(year col_country col_item desc_row DOM final)
saveold out0, replace
keep if desc_row=="INT" & DOM==0 & final==0
drop desc_row DOM final
ren value intermediate_imports_source
ren col_country row_country
ren col_item row_item
sort year row_country row_item
saveold intermediate_imports_by_source, replace
restore

preserve
* create a sectoral database: imported vs domestic 
collapse (sum) value, by(year col_country row_item desc_row DOM)
saveold out0, replace
keep if desc_row=="INT" & DOM==0
drop desc_row DOM
ren value total_imports_source
ren col_country row_country
sort year row_country row_item
merge 1:1 year row_country row_item using intermediate_imports_by_dest.dta, nogenerate
merge 1:1 year row_country row_item using intermediate_imports_by_source.dta, nogenerate
saveold "$datapath\imports.dta", replace
restore


**** Exports
preserve
* create a sectoral database: exported vs domestic intermediates
collapse (sum) value, by(year row_country row_item desc_row DOM final)
saveold out00, replace
keep if desc_row=="INT" & DOM==0 & final==0
drop desc_row DOM final
ren value intermediate_exports
sort year row_country row_item
saveold intermediate_exports.dta, replace

restore
preserve

* create a sectoral database: exported vs domestic 
collapse (sum) value, by(year row_country row_item desc_row DOM)
saveold out00, replace
keep if desc_row=="INT" & DOM==0
drop desc_row DOM
ren value total_exports
sort year row_country row_item
merge 1:1 year row_country row_item using intermediate_exports, nogenerate
gen final_exports = total_exports - intermediate_exports
saveold "$datapath\exports.dta", replace

restore


stop
* Fiddle with WIOD a little bit
global wiodpath "F:\DB_SSD\Dropbox (Osobiste)\projekty\vcproject\stuff (1)\Analysis\both\"
global datapath "C:\Users\Jan\Desktop\amadeus\do-files"

use "U_within World.dta", clear
merge m:1 row_country using groups, nogenerate
gen row_country2=row_country
replace row_country="EU15" if group=="EU15"



************** Merge all wiod data
global wiodpath "F:\DB_SSD\Dropbox (Osobiste)\projekty\vcproject\stuff (1)\Analysis\both\"
global datapath "C:\Users\Jan\Desktop\amadeus\do-files"

use "U_within World.dta", clear

*merge m:1 year row_country row_item using "$datapath\backward.dta", nogenerate
*merge m:1 year row_country row_item using "$datapath\forward.dta", nogenerate
merge m:1 year row_country row_item using "$datapath\imports.dta", nogenerate
merge m:1 year row_country row_item using "$datapath\exports.dta", nogenerate
merge m:1 year row_country row_item using "$datapath\output.dta", nogenerate


merge m:1 row_country using groups, nogenerate
gen row_country2=row_country
replace row_country2="EU15" if group=="EU15"


gen NMS=0
replace NMS=1 if row_country=="BGR" | row_country=="CZE" | row_country=="EST" | row_country=="HUN" | row_country=="LTU" | row_country=="LVA" | row_country=="POL"	| row_country=="ROU" | row_country=="SVK" | row_country=="SVN"

keep if NMS==1 | row_country2=="EU15"
gen l_U = log(U_w)
gen foreign_va_exports = for_vax / (intermediate_exports + final_exports)
gen domestic_va_exports = dom_vax / (intermediate_exports + final_exports)
gen inter_imports_output = intermediate_imports_dest / wiod_gross_output
gen share_exports = (intermediate_exports + final_exports) / wiod_gross_output
*gen total_exports = final_exports + intermediate_exports
gen inter_exports_exports = intermediate_exports / total_exports


